@@ -27,9 +27,26 @@
 #define BUF_SIZE 4096
 
 
+static int query_result(struct atmarp_req *reply)
+{
+    unsigned char *ipp = (unsigned char *) &reply->ip;
+    char buf[MAX_ATM_ADDR_LEN+1];
+    int error;
+
+    printf("IP:  %d.%d.%d.%d\n",ipp[0],ipp[1],ipp[2],ipp[3]);
+    if (!atmsvc_addr_in_use(reply->addr)) return 0;
+    error = atm2text(buf,sizeof(buf),(struct sockaddr *) &reply->addr,
+      A2T_PRETTY | A2T_NAME) < 0;
+    if (error) strcpy(buf,"<invalid>");
+    printf("ATM: %s\n",buf);
+    return error ? 1 : 0;
+}
+
+
 static int send_request(struct atmarp_req *req)
 {
-    int s,len,reply;
+    struct atmarp_req reply;
+    int s,len;
 
     s = un_attach(ATMARP_SOCKET_PATH);
     if (s < 0) {
@@ -45,15 +62,16 @@ static int send_request(struct atmarp_req *req)
 	perror("read");
 	exit(1);
     }
-    if (len != sizeof(reply)) {
-	fprintf(stderr,"bad read: %d != %d\n",len,sizeof(reply));
+    if (req->type == art_query) return query_result(&reply);
+    if (len != sizeof(int)) {
+	fprintf(stderr,"bad read: %d != %d\n",len,sizeof(int));
 	exit(1);
     }
-    if (reply < 0) {
-	fprintf(stderr,"atmarp: %s\n",strerror(-reply));
+    if (*(int *) &reply < 0) {
+	fprintf(stderr,"atmarp: %s\n",strerror(-*(int *) &reply));
 	exit(1);
     }
-    return reply;
+    return *(int *) &reply;
 }
 
 
@@ -90,6 +108,9 @@ static void usage(const char *name)
     fprintf(stderr,"%6s %s -s ip_addr atm_addr [pcr value] [qos spec] [temp] "
       "[pub] [arpsrv]\n","",name);
     fprintf(stderr,"%6s %s -d ip_addr [arpsrv]\n","",name);
+#if 0  /* undocumented */
+    fprintf(stderr,"%6s %s -Q ip_addr\n","",name);
+#endif
     exit(1);
 }
 
@@ -102,7 +123,7 @@ int main(int argc,char **argv)
     char *here,*end;
 
     req.type = 0;
-    while ((c = getopt(argc,argv,"acdqs")) != EOF)
+    while ((c = getopt(argc,argv,"acdqQs")) != EOF)
 	switch (c) {
 	    case 'a':
 		if (argc != optind || req.type) usage(argv[0]);
@@ -113,18 +134,22 @@ int main(int argc,char **argv)
 		if (req.type) usage(argv[0]);
 		req.type = art_create;
 		break;
+	    case 'd':
+		if (req.type) usage(argv[0]);
+		req.type = art_delete;
+		break;
 	    case 'q':
 		if (req.type) usage(argv[0]);
 		req.type = art_qos;
 		break;
+	    case 'Q':
+		if (req.type) usage(argv[0]);
+		req.type = art_query;
+		break;
 	    case 's':
 		if (req.type) usage(argv[0]);
 		req.type = art_set;
 		break;
-	    case 'd':
-		if (req.type) usage(argv[0]);
-		req.type = art_delete;
-		break;
 	    default:
 		usage(argv[0]);
 	}
@@ -150,6 +175,9 @@ int main(int argc,char **argv)
 	case art_set:
 	    if (argc < optind+2) usage(argv[0]);
 	    break;
+	case art_query:
+	    if (argc != optind+1) usage(argv[0]);
+	    break;
 	case art_delete:
 	    if (argc < optind+1) usage(argv[0]);
 	    break;
