@@ -308,8 +308,7 @@ int main(int argc, char *argv[])
       pid = fork();
       if(pid < 0)
 	diag(COMPONENT, DIAG_FATAL, "fork: %s", strerror(errno));
-      else if(pid > 0)
-	exit(0);
+      if(pid > 0) exit(0);
     }
   
   InitNibbleMem(512, 512);
