@@ -8,7 +8,7 @@
 #define CONN_H
 
 #include <unistd.h>
-#include <linux/atm.h>
+#include <atm.h>
 #include <sys/types.h>
 #include <sys/time.h>
 
