@@ -39,11 +39,12 @@
 #include <stdio.h>
 #include "codes.h"
 #include "g_types.h"
-#include "atm.h"
+#include "lane_atm.h"
 #include "system.h"
 #include "g_endian.h"
 #include "af_lane.h"
 #include "le_disp.h"
+#include "svc_info.h"    /* for CONN_INFO */
 
 const char *disp_status_text (UINT16 status)
    {
@@ -284,27 +285,23 @@ void le_frame_display (void   *frame,
    printf ("Illegal Frame\n");
    }
 
-void disp_sockaddr(struct sockaddr_atmsvc *addr)
+void disp_sockaddr(CONN_INFO *p_conn_info)
 {
   int i;
-  printf("Sas_family:%d\n\tAddress:",addr->sas_family);
+
+  printf("Sas_family:%d\n\tAddress:", p_conn_info->addr.sas_family);
   for(i=0;i<20;i++) {
-    printf("%2.2x ",addr->sas_addr.prv[i]);
+    printf("%2.2x ",p_conn_info->addr.sas_addr.prv[i]);
   }
-  if (!addr->sas_addr.blli) {
-    printf("No blli information\n");
-    fflush(stdout);
-  } else {
-    printf("\nBlli:\n\t");
-    printf("l2_proto:%d\n\t",addr->sas_addr.blli->l2_proto);
-    fflush(stdout);
-    printf("l3_proto:%d\n\t\t",addr->sas_addr.blli->l3_proto);
-    fflush(stdout);
-    printf("ipi:%x\tsnap:",addr->sas_addr.blli->l3.tr9577.ipi);
-    fflush(stdout);
-    for(i=0;i<5;i++) {
-      printf("%2.2x ",addr->sas_addr.blli->l3.tr9577.snap[i]);
-    }
-    printf("\n");
+  printf("\nBlli:\n\t");
+  printf("l2_proto:%d\n\t",p_conn_info->blli.l2_proto);
+  fflush(stdout);
+  printf("l3_proto:%d\n\t\t",p_conn_info->blli.l3_proto);
+  fflush(stdout);
+  printf("ipi:%x\tsnap:",p_conn_info->blli.l3.tr9577.ipi);
+  fflush(stdout);
+  for(i=0;i<5;i++) {
+    printf("%2.2x ",p_conn_info->blli.l3.tr9577.snap[i]);
   }
+  printf("\n");
 }
