@@ -490,56 +490,4 @@
       }                                         \
    }
 
-/*++
-* ================
-* = utl_mem_zero =
-* ================
-*
-* Overview:
-*   Clears all bytes of a virtually contiguous buffer to zero.
-*
-* Arguments:
-*   p_buf      - (IN)  Pointer to a memory buffer.
-*   size       - (IN)  Number of bytes in the buffer to be zeroed.
-* 
-* Returns:
-*   None
-*
-* Preconditions:
-*   There are at least 'size' bytes allocated to the buffer.
-*
-* Postconditions:
-*   The first 'size' bytes of the buffer are zero.
---*/
-void utl_mem_zero (void  *p_buf,
-                   int    size);
-
-
-/*++
-* ================
-* = utl_mem_copy =
-* ================
-*
-* Overview:
-*   Copies the indicated number of bytes from one buffer to another.
-*
-* Arguments:
-*   p_from     - (IN)  Pointer to the source memory buffer.
-*   p_to       - (IN)  Pointer to the destination memory buffer.
-*   size       - (IN)  Number of bytes in the buffer to be copied.
-* 
-* Returns:
-*   None
-*
-* Preconditions:
-*   There are at least 'size' bytes allocated to both buffers.
-*
-* Postconditions:
-*   The first 'size' bytes of the two buffers are identical to the input
-*   value of the source buffer.
---*/
-void utl_mem_copy (void  *p_from,
-                   void  *p_to,
-                   int    size);
-
 
