@@ -89,6 +89,18 @@ void expire_timers(void);
 
 /*--------------------------- Unix domain sockets ---------------------------*/
 
+
+#include <sys/socket.h>
+#include <sys/un.h>
+
+
+typedef struct {
+    int	s;			/* socket */
+    struct sockaddr_un addr;	/* reply address */
+    int size;			/* address size */
+} UN_CTX;
+
+
 int un_create(const char *path,mode_t mode);
 
 /*
@@ -124,4 +136,18 @@ int un_reply(int s,void *buf,int _size,
  * handler function.
  */
 
+int un_recv(UN_CTX *ctx,int s,void *buf,int size);
+
+/*
+ * Receive a message into the specified buffer and store the information needed
+ * to send a reply in ctx. Sets errno and returns a negative value on error.
+ */
+
+int un_send(const UN_CTX *ctx,void *buf,int len);
+
+/*
+ * Send a reply to the sender identified by ctx. Sets errno and returns a
+ * negative value on error.
+ */
+
 #endif
