@@ -1,6 +1,6 @@
 /* sonetdiag.c - SONET diagnostics */
 
-/* Written 1995-1997 by Werner Almesberger, EPFL-LRC */
+/* Written 1995-1998 by Werner Almesberger, EPFL-LRC/ICA */
 
 
 #include <stdlib.h>
@@ -10,7 +10,7 @@
 #include <sys/ioctl.h>
 #include <sys/types.h>
 #include <sys/socket.h>
-#include <linux/atm.h>
+#include <atm.h>
 #include <linux/atmdev.h>
 #include <linux/sonet.h>
 
