@@ -15,6 +15,7 @@
 #include "dispatch.h"
 #include "proto.h"
 #include "sig.h"
+#include "route.h"
 #include "fab.h"
 
 
@@ -95,8 +96,9 @@ static void up_callback(CALL *call,int cause,void *more,void *user)
 	diag(COMPONENT,DIAG_FATAL,"un_attach %s: %s",sig->path,strerror(errno));
     send_listen(sig);
     error = sig_recv(sig,sig_check_listen);
-    if (!error) dsp_fd_add(sig->s,sig_data,sig);
-    else diag(COMPONENT,DIAG_FATAL,"listen failed: %s",strerror(error));
+    if (error) diag(COMPONENT,DIAG_FATAL,"listen failed: %s",strerror(error));
+    dsp_fd_add(sig->s,sig_data,sig);
+    route_sig(sig,&sig->call->out.pvc,1);
 }
 
 
@@ -143,6 +145,7 @@ void sig_notify(int itf,int up)
 	fab_op(sig->call,RM_CLAIM(_RM_ANY),&qos,up_callback,sig);
     }
     else {
+	route_sig(sig,&sig->call->out.pvc,0);
 	remove_entity(sig);
 	fab_op(sig->call,RM_FREE,NULL,down_callback,NULL);
 	free_call(sig->call);
